# @dao-style/vue-cli-plugin-lint

**peerDependencies:**

```json
"@vue/cli-service": "^5.0.0-0"
```

**usage:**

```js
//1.install
vue add #@dao-style/vue-cli-plugin-lint

//2.lint
npm run lint
npm run lint:style 
npm run lint:type
npm run lint:es

git add .
npx run lint-staged

//3.commit
npm run commit //利用commitizen 辅助填写提交信息
//或者

// git commit -m '<type>[scope]: <subject>

// [body]

// [footer]'

//符合conventional提交规范
```

## Stylelint

**package.json :**

```json
{
     "scripts":{
        "lint:style": "stylelint \"src/**/*.{vue,scss,css}\" --config .stylelintrc.js --fix",
    }
    "devDependencies":{
       "stylelint": "^14.3.0",
        "postcss-html": "^1.3.0",
        "stylelint-config-recommended-vue": "^1.1.0",
        "stylelint-config-recess-order": "^3.0.0",
        "stylelint-config-sass-guidelines": "^9.0.1", 

       
    }
    
}

```

**.stylelintrc.js extends:**

> stylelint-config-recommended-vue 在最后

[
  ["stylelint-config-recess-order"](https://github.com/stormwarning/stylelint-config-recess-order),
  ["stylelint-config-sass-guidelines"](https://github.com/bjankord/stylelint-config-sass-guidelines),
  ["stylelint-config-recommended-vue"](https://github.com/ota-meshi/stylelint-config-recommended-vue),
]

## Eslint

**package.json :**

```json
{
  "scripts":{
    "lint:es": "eslint \"src/**/*.{js,jsx,ts,tsx,vue}\" --config .eslintrc.js --fix --max-warnings=0",
  }
  "devDependencies":{
    "eslint": "^8.7.0",
    "eslint-plugin-json": "^3.1.0",
    "eslint-plugin-vue": "^8.4.0",
    "@vue/eslint-config-airbnb": "^6.0.0",
    "eslint-plugin-vuejs-accessibility": "^1.1.1",

    //ts
    "@typescript-eslint/eslint-plugin": "^5.10.1",
    "@typescript-eslint/parser": "^5.10.1",
    "@vue/cli-plugin-typescript": "~5.0.0-rc.2",
    "@vue/eslint-config-typescript": "^9.1.0",
  }
  
}

```

**.eslintrc.js:**

```js
{
  parserOptions: {
    ecmaVersion: 2020,
    parser: "@typescript-eslint/parser",
    sourceType: "module",
    extraFileExtensions: [".vue"],
  },
  plugins: ["vue", "@typescript-eslint"],
  extends: [
    "plugin:json/recommended",
    "plugin:vue/vue3-recommended",
    "@vue/airbnb",
    "@vue/typescript/recommended",
  ],
  rules:{
    ,//https://github.com/typescript-eslint/typescript-eslint/issues/2483
    'no-shadow': 'off',
    '@typescript-eslint/no-shadow': 'error'
  }
}
```

[plugin:vue/vue3-recommended](https://eslint.vuejs.org/rules/attributes-order.html)
[plugin:json/recommended](https://github.com/azeemba/eslint-plugin-json)

## CommitLint

- lint规则：符合conventional提交规范。

- commitizen辅助填写提交信息。

**package.json :**

```json
{
     "scripts": {
      "commit": "git-cz",
    },
    "config": {
      "commitizen": {
        "path": "@commitlint/cz-commitlint",
      },
    },
    "devDependencies": {
      "@commitlint/cli": "^16.0.2",
      "@commitlint/config-conventional": "^16.0.0",
      "@commitlint/cz-commitlint": "^16.0.0",
      "commitizen": "^4.2.4",
    },
    "gitHooks": {
      "commit-msg": "commitlint -E GIT_PARAMS",
    },
}
```
