const {
  readFileSync, mkdirSync, writeFileSync, rmSync,
} = require('fs');
const {
  resolve,
  isTargetExist,
} = require('@yanhe-su/vue-cli-plugin-shared-utils/lib/utils');

module.exports = () => {
  const lintSetting = {
    'editor.codeActionsOnSave': {
      'source.fixAll': true,
      'source.fixAll.eslint': true,
      'source.fixAll.stylelint': true,
    },
    'eslint.alwaysShowStatus': true,
    'eslint.options': {
      extensions: [
        '.ts',
        '.tsx',
        '.js',
        '.jsx',
        '.vue',
      ],
    },
    'eslint.validate': [
      'javascript',
      'html',
      'vue',
      'vue-html',
      'html',
      'json',
      'jsonc',
      'json5',
    ],
    'stylelint.snippet': [
      'css',
      'less',
      'postcss',
      'vue',
      'scss',
      'sass',
    ],
    'stylelint.validate': [
      'css',
      'less',
      'postcss',
      'vue',
      'scss',
      'sass',
    ],
    'stylelint.packageManager': 'npm',
    '[json]': {
      'editor.defaultFormatter': 'dbaeumer.vscode-eslint',
    },
    '[javascript]': {
      'editor.defaultFormatter': 'dbaeumer.vscode-eslint',
    },
    '[typescript]': {
      'editor.defaultFormatter': 'dbaeumer.vscode-eslint',
    },
  };

  const lintExtension = {
    recommendations: [
      'Vue.volar',
      'Vue.vscode-typescript-vue-plugin',
      'dbaeumer.vscode-eslint',
      'stylelint.vscode-stylelint',
    ],
  };

  const isVscodeExist = isTargetExist('./.vscode');

  if (!isVscodeExist) {
    mkdirSync(resolve('./.vscode'));
  }

  const isSettingExist = isTargetExist('./.vscode/settings.json');

  const settingPos = resolve('./.vscode/settings.json');

  if (!isSettingExist) {
    writeFileSync(settingPos, '{}');
  }
  const isExtensionExist = isTargetExist('./.vscode/extensions.json');

  const extensionPos = resolve('./.vscode/extensions.json');

  if (!isExtensionExist) {
    writeFileSync(extensionPos, '{}');
  }

  const settings = JSON.parse(
    readFileSync(settingPos, {
      encoding: 'utf-8',
    }),
  );

  Object.assign(settings, lintSetting);

  rmSync(settingPos);

  writeFileSync(settingPos, `${JSON.stringify(settings, null, 2)}\n`);

  const extensions = JSON.parse(
    readFileSync(extensionPos, {
      encoding: 'utf-8',
    }),
  );

  if (!extensions.recommendations) {
    extensions.recommendations = [];
  }

  extensions.recommendations = extensions.recommendations.concat(lintExtension.recommendations);
  extensions.recommendations = [...new Set(extensions.recommendations)];

  rmSync(extensionPos);

  writeFileSync(extensionPos, `${JSON.stringify(extensions, null, 2)}\n`);
};
