const path = require('path');

const vuejsAccessibilityOff = Object.keys(
  require(path.resolve(path.dirname(require.resolve('eslint-plugin-vuejs-accessibility')), '../dist/index')).rules,
).reduce((rules, rule) => {
  rules[`vuejs-accessibility/${rule}`] = 0;

  return rules;
}, {});

module.exports = {
  root: true,
  env: {
    es6: true,
    node: true,
    jest: true,
    browser: true,
  },
  parser: 'vue-eslint-parser',
  plugins: ['vue'],
  extends: [
    'plugin:jsonc/recommended-with-json',
    'plugin:vue/vue3-recommended',
    '@vue/airbnb',
  ],
  rules: {
    "jsonc/indent": ["error", 2],
    'comma-spacing': ['error', { before: false, after: true }],
    quotes: ['error', 'single'],
    'jsx-quotes': ['error', 'prefer-double'],
    'vue/html-quotes': ['error', 'double', { avoidEscape: true }],
    'max-statements-per-line': ['error', { max: 1 }],
    'vue/multiline-html-element-content-newline': ['error'], // 多行html中的内容是否独占一行
    'vue/singleline-html-element-content-newline': ['error'],
    'vue/max-attributes-per-line': [
      'error',
      {
        singleline: {
          max: 1,
        },
        multiline: {
          max: 1,
        },
      },
    ],
    'array-bracket-newline': ['error', 'consistent'], // []新一行
    'vue/array-bracket-newline': ['error', 'consistent'],
    'comma-dangle': ['error', 'always-multiline'], // 最后一个对象元素加逗号
    'object-property-newline': ['error', { allowAllPropertiesOnSameLine: false }],
    'vue/object-property-newline': ['error', { allowAllPropertiesOnSameLine: false }],
    'vue/space-infix-ops': ['error', { int32Hint: true }],
    'vue/object-curly-spacing': ['error', 'always'], // 对象内的间距要求
    'vue/comma-spacing': ['error'], // 对象内的逗号位置
    'vue/key-spacing': ['error'], // 冒号位置

    'no-console': process.env.NODE_ENV === 'production' ? 'warn' : 'off',
    'no-debugger': process.env.NODE_ENV === 'production' ? 'warn' : 'off',
    'import/prefer-default-export': 0,
    'import/no-extraneous-dependencies': 0,
    'import/no-unresolved': 0,
    'import/extensions': [
      'error',
      'ignorePackages',
      {
        js: 'never',
        mjs: 'never',
        jsx: 'never',
      },
    ],
    ...vuejsAccessibilityOff,
  },
  overrides: [
    {
      files: ['**/__tests__/*.{j,t}s?(x)', '**/tests/unit/**/*.spec.{j,t}s?(x)'],
      env: {
        jest: true,
      },
    },
  ],
};
